 /*
 * file      : src/page.c
 * project   : tm
 * with      : Gtk-2
 *
 * copyright : (C) 2012 by Claude BULIN
 *
 * TM - Edition des heures de travail / Edition of working hours
 * GNU General Public License
 * 
 * This file is part of TM.
 * 
 * TM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * TM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TM.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
	#define gettext_noop(x) (x) 
#endif

#include <gtk/gtk.h>
#include <string.h>
#include <stdlib.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_tm/lib.h"
#endif

#include "global.h"
#include "callbacks.h"



ALL_PAGES AllPages = {
	0,							// NbrPages
	NULL							// struct ALL_PAGES
	};




// 
//
void page_search_posX_ps( void )
{
	GList		*ListPages = NULL;
	LINE		*Line = NULL;
	GList		*ListLines = NULL;
	LINE_OF_PAGE	*Details = NULL;
	gint		HeightPage = _SIZE_ONE_PAGE_;
	gint		Page = 1;
	
	if( NULL != AllPages.Page ) {
		ListPages = g_list_first( AllPages.Page );
		while( ListPages ) {
			if( NULL != (Line = (LINE *)ListPages->data)) {
				
				// g_print("Page %d\n", Page );
				ListLines = g_list_first( Line->LineDetail );
				while( ListLines ) {
					if( NULL != (Details = (LINE_OF_PAGE *)ListLines->data) ) {
						
						if( LINE_GRAPH == Details->LineType ) {
							Details->PosYPS = ((Page * HeightPage) - (gint)Details->LinePosY);
						} else {
							Details->PosYPS = ((Page * HeightPage) - (gint)Details->PosY);
						}
					}
					ListLines = g_list_next( ListLines );
				}
			}
			ListPages = g_list_next( ListPages );
			Page ++;
		}
		g_print("\n");
	}
}
// 
//
void page_list_remove( void )
{
	GList		*ListPages = NULL;
	LINE		*Line = NULL;
	GList		*ListLines = NULL;
	LINE_OF_PAGE	*Details = NULL;
	
	if( NULL != AllPages.Page ) {
		ListPages = g_list_first( AllPages.Page );
		while( ListPages ) {
			if( NULL != (Line = (LINE *)ListPages->data)) {
			
				ListLines = g_list_first( Line->LineDetail );
				while( ListLines ) {
					if( NULL != (Details = (LINE_OF_PAGE *)ListLines->data) ) {
						if( NULL != Details->Str ) {
							g_free( Details->Str );
							Details->Str = NULL;
						}
						g_free( Details );
						Details = ListLines->data = NULL;
					}
					ListLines = g_list_next( ListLines );
				}
				g_list_free( Line->LineDetail );
				Line->LineDetail = NULL;
			}
			ListPages = g_list_next( ListPages );
		}
		g_list_free( AllPages.Page );
		AllPages.Page = NULL;
	}
	// INIT STRUCT
	AllPages.NbrPages = 0;
	AllPages.Page     = NULL;
}
// 
//
void page_create( void )
{
	LINE	*NewLine = NULL;
	
	// ALLOCATE STRUCT
	NewLine = (LINE *)g_malloc0( sizeof(LINE) );
	NewLine->LineDetail = NULL;
	// ADD STRUCT TO GLIST
	AllPages.Page = g_list_append( AllPages.Page, NewLine );
	// INIT NUMBERS PAGES
	AllPages.NbrPages = g_list_length( AllPages.Page );
}
// 
//
void page_list_alloc( LINE_TYPE p_LineType )
{
	LINE_OF_PAGE	*Details = NULL;
	GList		*ListPages = NULL;
	LINE		*Line = NULL;
	
	Details = (LINE_OF_PAGE *)g_malloc0( sizeof( LINE_OF_PAGE ));
	// INIT Details ...
	Details->LineType       = p_LineType;
	Details->PosX           = 0.0;
	Details->PosY           = 0.0;
	Details->PosXPS         = 0.0;
	Details->PosYPS         = 0.0;
	Details->PosXLine       = 0.0;
	Details->TypeColor      = COLOR_BLACK;
	Details->FontSlantType  = FONT_SLANT_NORMAL;
	Details->FontWeightType = FONT_WEIGHT_NORMAL;
	
	Details->SizeFont       = p_LineType == NOUVELLE_PAGE ? VarDraw.SizeFontTitle : VarDraw.SizeFontName;
	
	Details->Str            = NULL;
	Details->LenStr         = 0.0;
	Details->LinePosX       = 0.0;
	Details->LinePosY       = 0.0;
	Details->LineLen        = 0.0;

	ListPages = g_list_last( AllPages.Page );
	if( NULL != (Line = (LINE *)ListPages->data)) {
		Line->LineDetail = g_list_append( Line->LineDetail, Details );
	}
	
}
// 
//
LINE_OF_PAGE *page_get_ptr_last_data( void )
{
	GList		*LastListOfPages = NULL;
	GList		*ListOfLines = NULL;
	LINE		*EndList = NULL;

	LastListOfPages = g_list_last( AllPages.Page );
	EndList = (LINE *)LastListOfPages->data;
	ListOfLines = g_list_last( EndList->LineDetail );
	return( (LINE_OF_PAGE *)ListOfLines->data );
}
// 
//
void page_add_PosX( gdouble p_PosX )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->PosX   = p_PosX;
		Details->PosXPS = p_PosX;
	}
}
// 
//
gdouble page_add_PosY( gdouble p_PosY )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->PosY   = p_PosY;
		Details->PosYPS = p_PosY;
	}
	return( p_PosY );
}
// 
//
void page_add_PosXLine( gdouble p_PosXLine )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->PosXLine = p_PosXLine;
	}
}
// 
//
void page_add_font_color( TYPE_COLOR p_TypeColor )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->TypeColor = p_TypeColor;
	}
}
// 
//
void page_add_font_slant( FONT_SLANT_TYPE p_FontSlantType )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->FontSlantType = p_FontSlantType;
	}
}
// 
//
void page_add_font_weight( FONT_WEIGHT_TYPE p_FontWeightType )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->FontWeightType = p_FontWeightType;
	}
}
// 
//
void page_add_str( gchar *p_Str )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->Str = g_strdup( p_Str );
	}
}
// 
//
void page_add_line( gdouble p_LinePosX, gdouble p_LinePosY, gdouble p_LineLen )
{
	LINE_OF_PAGE	*Details = NULL;

	if( NULL != (Details = (LINE_OF_PAGE *)page_get_ptr_last_data()) ) {
		Details->LinePosX = p_LinePosX;
		Details->LinePosY = p_LinePosY;
		Details->LineLen  = p_LineLen;
		
		Details->PosXPS   = p_LinePosX;
		Details->PosYPS   = p_LinePosY;
	}
}









